Welcome to Orange3 Explain documentation!
=========================================


Widgets
-------

.. toctree::
   :maxdepth: 1

   widgets/permutation-importance
   widgets/explain-model
   widgets/explain-prediction
   widgets/explain-predictions
   widgets/ice

Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
